/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.survey.tool');

org.ametys.survey.tool.SurveyPreviewToolFactory = function(id, config, pluginName) 
{
	org.ametys.survey.tool.SurveyPreviewToolFactory.superclass.constructor.call(this, id, config, pluginName);
};

Ext.extend(org.ametys.survey.tool.SurveyPreviewToolFactory, org.ametys.uitool.tool.ToolFactory, {});

org.ametys.survey.tool.SurveyPreviewToolFactory._toolIdPrefix = "survey-preview-";

/**
 * Creates a tool of type {@see org.ametys.survey.tool.SurveyPreviewTool} or activate the existing one.
 * There is one tool per content.
 * @param {Map} params The params used by the factory is 'id' that is the survey id. Params are transmited the the survey tool.
 * @return {Ext.org.ametys.uitool.tool.Tool} The tool to open.
 */
org.ametys.survey.tool.SurveyPreviewToolFactory.prototype.openTool = function (params)
{
	if (org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.survey.tool.SurveyPreviewToolFactory._toolIdPrefix + params.id) == null)
	{
		this._config['title'] = params.id;
		var tool = new org.ametys.survey.tool.SurveyPreviewTool (org.ametys.survey.tool.SurveyPreviewToolFactory._toolIdPrefix + params.id, this.getPluginName());
		
		tool.setConfiguration(this._config);
		tool.setFactory (this);
		
		org.ametys.uitool.ToolsManager.getInstance().addUITool (tool, this._config['default-location']);
	}
	else
	{
		// Tool does already exist => Tool activation
		tool = org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.survey.tool.SurveyPreviewToolFactory._toolIdPrefix + params.id);
	}

	tool.setParams(params);
	tool.activate();

	return tool;
	
}
/**
 * Destroy the tool.
 * @param {org.ametys.uitool.tool.Tool} tool The tool to close.
 */
org.ametys.survey.tool.SurveyPreviewToolFactory.prototype.closeTool = function (tool)
{
	org.ametys.uitool.ToolsManager.getInstance().removeUITool (tool);
}